import { VersionedTransaction } from '@solana/web3.js';
import { EIP1193Provider, Account } from 'viem';

type BaseExternalWalletSignerConfig = {
    type: "external-wallet";
    address?: string;
};
interface GenericEIP1193Provider {
    request(args: {
        method: string;
        params?: any[];
    }): Promise<any>;
    on(event: string, listener: (...args: any[]) => void): void;
    removeListener(event: string, listener: (...args: any[]) => void): void;
}
type EvmExternalWalletSignerConfig = BaseExternalWalletSignerConfig & {
    provider?: GenericEIP1193Provider | EIP1193Provider;
    viemAccount?: Account;
};
type SolanaExternalWalletSignerConfig = BaseExternalWalletSignerConfig & {
    onSignTransaction?: (transaction: VersionedTransaction) => Promise<VersionedTransaction>;
};

export type { BaseExternalWalletSignerConfig, EvmExternalWalletSignerConfig, GenericEIP1193Provider, SolanaExternalWalletSignerConfig };
